1 new commit in galaxy-central:
https://bitbucket.org/galaxy/galaxy-central/changeset/4f17b0d16ff7/
changeset: 4f17b0d16ff7
user: carlfeberhard
date: 2012-08-07 21:57:13
summary: fix to rusted display_string in TestLibraryFeatures.test_100_add_ldda_to_folder3
affected #: 1 file
diff -r 1cb2fdf2c7cf22d74ec46e6877609f7056372d7c -r 4f17b0d16ff7b878fba9c6e8730998ee61c54c5e test/functional/test_library_templates.py
--- a/test/functional/test_library_templates.py
+++ b/test/functional/test_library_templates.py
@@ -398,7 +398,7 @@
folder_id=self.security.encode_id( folder3.id ),
upload_option='import_from_history',
hda_ids=self.security.encode_id( hda.id ),
- strings_displayed=[ '<input type="hidden" name="%s" value="Option1"/>' % select_field_name ] )
+ strings_displayed=[ '<select name="%s" last_selected_value="Option1">' % select_field_name ] )
ldda = get_latest_ldda_by_name( filename )
assert ldda is not None, 'Problem retrieving LibraryDatasetDatasetAssociation ldda from the database'
self.browse_library( cntrller='library_admin',
Repository URL: https://bitbucket.org/galaxy/galaxy-central/
--
This is a commit notification from bitbucket.org. You are receiving
this because you have the service enabled, addressing the recipient of
this email.
1 new commit in galaxy-central:
https://bitbucket.org/galaxy/galaxy-central/changeset/1cb2fdf2c7cf/
changeset: 1cb2fdf2c7cf
user: greg
date: 2012-08-07 20:42:28
summary: Ensure repository metadata records are unique in the tool shed.
affected #: 1 file
diff -r ca835611e8c79a9b95c50acc28d670f7f81266e7 -r 1cb2fdf2c7cf22d74ec46e6877609f7056372d7c lib/galaxy/webapps/community/controllers/common.py
--- a/lib/galaxy/webapps/community/controllers/common.py
+++ b/lib/galaxy/webapps/community/controllers/common.py
@@ -238,10 +238,17 @@
reset_tool_data_tables( trans.app )
return can_set_metadata, invalid_files
def clean_repository_metadata( trans, id, changeset_revisions ):
- # Delete all repository_metadata reecords associated with the repository that have a changeset_revision that is not in changeset_revisions.
+ # Delete all repository_metadata records associated with the repository that have a changeset_revision that is not in changeset_revisions.
+ # We sometimes see multiple records with the same changeset revision value - no idea how this happens. We'll assume we can delete the older
+ # records, so we'll order by update_time descending and delete records that have the same changeset_revision we come across later..
+ changeset_revisions_checked = []
for repository_metadata in trans.sa_session.query( trans.model.RepositoryMetadata ) \
- .filter( trans.model.RepositoryMetadata.table.c.repository_id == trans.security.decode_id( id ) ):
- if repository_metadata.changeset_revision not in changeset_revisions:
+ .filter( trans.model.RepositoryMetadata.table.c.repository_id == trans.security.decode_id( id ) ) \
+ .order_by( trans.model.RepositoryMetadata.table.c.changeset_revision,
+ trans.model.RepositoryMetadata.table.c.update_time.desc() ):
+ changeset_revision = repository_metadata.changeset_revision
+ can_delete = changeset_revision in changeset_revisions_checked or changeset_revision not in changeset_revisions
+ if can_delete:
trans.sa_session.delete( repository_metadata )
trans.sa_session.flush()
def compare_changeset_revisions( ancestor_changeset_revision, ancestor_metadata_dict, current_changeset_revision, current_metadata_dict ):
@@ -874,9 +881,8 @@
if 'workflows' in metadata_dict:
repository_metadata = get_latest_repository_metadata( trans, repository.id )
if repository_metadata:
- if repository_metadata.metadata:
- # The repository has metadata, so update the workflows value - no new record is needed.
- return False
+ # The repository has metadata, so update the workflows value - no new record is needed.
+ return False
else:
# There is no saved repository metadata, so we need to create a new repository_metadata table record.
return True
Repository URL: https://bitbucket.org/galaxy/galaxy-central/
--
This is a commit notification from bitbucket.org. You are receiving
this because you have the service enabled, addressing the recipient of
this email.
1 new commit in galaxy-central:
https://bitbucket.org/galaxy/galaxy-central/changeset/f4e633e6ab4e/
changeset: f4e633e6ab4e
user: greg
date: 2012-08-07 19:43:36
summary: Fix mercurial command line handling for pushes from the command line that were broken in change set d19fbfefb676 for versions of mercurial older than 2.2.3. Pushes should now function correctly for those running mercurial older than version 2.2.3.
affected #: 2 files
diff -r 3f17b65c590758f03c517cc564d59efcc5f3998c -r f4e633e6ab4e3f319f02a33fd21cbccfda2a80c1 lib/galaxy/webapps/community/controllers/hg.py
--- a/lib/galaxy/webapps/community/controllers/hg.py
+++ b/lib/galaxy/webapps/community/controllers/hg.py
@@ -1,9 +1,12 @@
import os, logging
from galaxy.web.base.controller import *
from galaxy.webapps.community.controllers.common import *
+from galaxy.util.shed_util import update_repository
from galaxy import eggs
eggs.require('mercurial')
+import mercurial.__version__
+from mercurial import hg, ui, commands
from mercurial.hgweb.hgwebdir_mod import hgwebdir
from mercurial.hgweb.request import wsgiapplication
@@ -14,17 +17,32 @@
def handle_request( self, trans, **kwd ):
# The os command that results in this method being called will look something like
# hg clone http://test@127.0.0.1:9009/repos/test/convert_characters1
+ hg_version = mercurial.__version__.version
cmd = kwd.get( 'cmd', None )
wsgi_app = wsgiapplication( make_web_app )
- if cmd == 'pushkey':
- # This results from an "hg push" from the command line. When doing this, the following 6 commands, in order,
- # will be retrieved from environ: capabilities -> batch -> branchmap -> unbundle -> listkeys -> pushkey
+ # In mercurial version 2.2.3, section 15.2. Command changes includes a new feature: pushkey: add hooks for pushkey/listkeys (see
+ # http://mercurial.selenic.com/wiki/WhatsNew#Mercurial_2.2.3_.282012-07-01.29). Older versions require checking for 'listkeys'.
+ push_from_command_line = ( hg_version < '2.2.3' and cmd == 'listkeys' ) or ( hg_version >= '2.2.3' and cmd == 'pushkey' )
+ if push_from_command_line:
+ # When doing an "hg push" from the command line, the following commands, in order, will be retrieved from environ, depending
+ # upon the mercurial version being used. There is a weakness if the mercurial version < '2.2.3' because several commands include
+ # listkeys, so repository metadata will be set, but only for the files currently on disk, so doing so is not too expensive.
+ # If mercurial version < '2.2.3:
+ # capabilities -> batch -> branchmap -> unbundle -> listkeys
+ # If mercurial version >= '2.2.3':
+ # capabilities -> batch -> branchmap -> unbundle -> listkeys -> pushkey
path_info = kwd.get( 'path_info', None )
if path_info:
owner, name = path_info.split( '/' )
repository = get_repository_by_name_and_owner( trans, name, owner )
if repository:
- error_message, status = reset_all_metadata_on_repository( trans, trans.security.encode_id( repository.id ) )
+ if hg_version < '2.2.3':
+ # We're forced to update the repository so the disk files include the changes in the push. This is handled in the
+ # pushkey hook in mercurial version 2.2.3 and newer.
+ repo = hg.repository( ui.ui(), repository.repo_path )
+ update_repository( repo )
+ # Set metadata using the repository files on disk.
+ error_message, status = set_repository_metadata( trans, repository )
if status not in [ 'ok' ] and error_message:
log.debug( "Error resetting metadata on repository '%s': %s" % ( str( repository.name ), str( error_message ) ) )
elif status in [ 'ok' ] and error_message:
diff -r 3f17b65c590758f03c517cc564d59efcc5f3998c -r f4e633e6ab4e3f319f02a33fd21cbccfda2a80c1 lib/galaxy/webapps/community/framework/middleware/hg.py
--- a/lib/galaxy/webapps/community/framework/middleware/hg.py
+++ b/lib/galaxy/webapps/community/framework/middleware/hg.py
@@ -8,11 +8,13 @@
from galaxy.webapps.community import model
from galaxy.util.hash_util import new_secure_hash
+import mercurial.__version__
log = logging.getLogger(__name__)
class Hg( object ):
def __init__( self, app, config ):
+ print "mercurial version is:", mercurial.__version__.version
self.app = app
self.config = config
# Authenticate this mercurial request using basic authentication
@@ -56,7 +58,7 @@
connection.close()
if cmd == 'unbundle':
# This is an hg push from the command line. When doing this, the following 7 commands, in order,
- # will be retrieved from environ:
+ # will be retrieved from environ (see the docs at http://mercurial.selenic.com/wiki/WireProtocol):
# between -> capabilities -> heads -> branchmap -> unbundle -> unbundle -> listkeys
#
# The mercurial API unbundle() ( i.e., hg push ) method ultimately requires authorization.
Repository URL: https://bitbucket.org/galaxy/galaxy-central/
--
This is a commit notification from bitbucket.org. You are receiving
this because you have the service enabled, addressing the recipient of
this email.
1 new commit in galaxy-central:
https://bitbucket.org/galaxy/galaxy-central/changeset/fc9b4ae154ef/
changeset: fc9b4ae154ef
user: jgoecks
date: 2012-08-07 15:52:14
summary: Update track icons when decomposing a composite track into individual tracks.
affected #: 1 file
diff -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc -r fc9b4ae154efd2d8fb02c3637835a82767898be4 static/scripts/viz/trackster.js
--- a/static/scripts/viz/trackster.js
+++ b/static/scripts/viz/trackster.js
@@ -4067,6 +4067,7 @@
track;
for (var i = 0; i < this.drawables.length; i++) {
track = this.drawables[i];
+ track.update_icons();
group.add_drawable(track);
track.container = group;
group.content_div.append(track.container_div);
Repository URL: https://bitbucket.org/galaxy/galaxy-central/
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc templates/tool_form.mako
--- a/templates/tool_form.mako
+++ b/templates/tool_form.mako
@@ -332,6 +332,9 @@
else:
tool_help = tool.help
+ # Help is Mako template, so render using current static path.
+ tool_help = tool_help.render( static_path=h.url_for( '/static' ) )
+
# Convert to unicode to display non-ascii characters.
if type( tool_help ) is not unicode:
tool_help = unicode( tool_help, 'utf-8')
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/discreteWavelet/execute_dwt_IvC_all.xml
--- a/tools/discreteWavelet/execute_dwt_IvC_all.xml
+++ b/tools/discreteWavelet/execute_dwt_IvC_all.xml
@@ -101,11 +101,11 @@
The second output file:
-.. image:: ./static/operation_icons/dwt_IvC_1.png
-.. image:: ./static/operation_icons/dwt_IvC_2.png
-.. image:: ./static/operation_icons/dwt_IvC_3.png
-.. image:: ./static/operation_icons/dwt_IvC_4.png
-.. image:: ./static/operation_icons/dwt_IvC_5.png
+.. image:: ${static_path}/operation_icons/dwt_IvC_1.png
+.. image:: ${static_path}/operation_icons/dwt_IvC_2.png
+.. image:: ${static_path}/operation_icons/dwt_IvC_3.png
+.. image:: ${static_path}/operation_icons/dwt_IvC_4.png
+.. image:: ${static_path}/operation_icons/dwt_IvC_5.png
</help>
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/discreteWavelet/execute_dwt_cor_aVa_perClass.xml
--- a/tools/discreteWavelet/execute_dwt_cor_aVa_perClass.xml
+++ b/tools/discreteWavelet/execute_dwt_cor_aVa_perClass.xml
@@ -101,11 +101,11 @@
The second output file:
-.. image:: ./static/operation_icons/dwt_cor_aVa_1.png
-.. image:: ./static/operation_icons/dwt_cor_aVa_2.png
-.. image:: ./static/operation_icons/dwt_cor_aVa_3.png
-.. image:: ./static/operation_icons/dwt_cor_aVa_4.png
-.. image:: ./static/operation_icons/dwt_cor_aVa_5.png
+.. image:: ${static_path}/operation_icons/dwt_cor_aVa_1.png
+.. image:: ${static_path}/operation_icons/dwt_cor_aVa_2.png
+.. image:: ${static_path}/operation_icons/dwt_cor_aVa_3.png
+.. image:: ${static_path}/operation_icons/dwt_cor_aVa_4.png
+.. image:: ${static_path}/operation_icons/dwt_cor_aVa_5.png
</help>
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/discreteWavelet/execute_dwt_cor_aVb_all.xml
--- a/tools/discreteWavelet/execute_dwt_cor_aVb_all.xml
+++ b/tools/discreteWavelet/execute_dwt_cor_aVb_all.xml
@@ -106,16 +106,16 @@
The second output file:
-.. image:: ./static/operation_icons/dwt_cor_aVb_all_1.png
-.. image:: ./static/operation_icons/dwt_cor_aVb_all_2.png
-.. image:: ./static/operation_icons/dwt_cor_aVb_all_3.png
-.. image:: ./static/operation_icons/dwt_cor_aVb_all_4.png
-.. image:: ./static/operation_icons/dwt_cor_aVb_all_5.png
-.. image:: ./static/operation_icons/dwt_cor_aVb_all_6.png
-.. image:: ./static/operation_icons/dwt_cor_aVb_all_7.png
-.. image:: ./static/operation_icons/dwt_cor_aVb_all_8.png
-.. image:: ./static/operation_icons/dwt_cor_aVb_all_9.png
-.. image:: ./static/operation_icons/dwt_cor_aVb_all_10.png
+.. image:: ${static_path}/operation_icons/dwt_cor_aVb_all_1.png
+.. image:: ${static_path}/operation_icons/dwt_cor_aVb_all_2.png
+.. image:: ${static_path}/operation_icons/dwt_cor_aVb_all_3.png
+.. image:: ${static_path}/operation_icons/dwt_cor_aVb_all_4.png
+.. image:: ${static_path}/operation_icons/dwt_cor_aVb_all_5.png
+.. image:: ${static_path}/operation_icons/dwt_cor_aVb_all_6.png
+.. image:: ${static_path}/operation_icons/dwt_cor_aVb_all_7.png
+.. image:: ${static_path}/operation_icons/dwt_cor_aVb_all_8.png
+.. image:: ${static_path}/operation_icons/dwt_cor_aVb_all_9.png
+.. image:: ${static_path}/operation_icons/dwt_cor_aVb_all_10.png
</help>
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/discreteWavelet/execute_dwt_var_perClass.xml
--- a/tools/discreteWavelet/execute_dwt_var_perClass.xml
+++ b/tools/discreteWavelet/execute_dwt_var_perClass.xml
@@ -98,7 +98,7 @@
The third output file:
-.. image:: ./static/operation_icons/dwt_var_perClass.png
+.. image:: ${static_path}/operation_icons/dwt_var_perClass.png
</help>
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/evolution/add_scores.xml
--- a/tools/evolution/add_scores.xml
+++ b/tools/evolution/add_scores.xml
@@ -43,8 +43,8 @@
The input can be any interval_ format dataset. The output is also in interval format.
(`Dataset missing?`_)
-.. _interval: ./static/formatHelp.html#interval
-.. _Dataset missing?: ./static/formatHelp.html
+.. _interval: ${static_path}/formatHelp.html#interval
+.. _Dataset missing?: ${static_path}/formatHelp.html
-----
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/evolution/codingSnps.xml
--- a/tools/evolution/codingSnps.xml
+++ b/tools/evolution/codingSnps.xml
@@ -94,9 +94,9 @@
The gene dataset is in BED_ format with 12 columns. The output dataset is also interval.
(`Dataset missing?`_)
-.. _interval: ./static/formatHelp.html#interval
-.. _BED: ./static/formatHelp.html#bed
-.. _Dataset missing?: ./static/formatHelp.html
+.. _interval: ${static_path}/formatHelp.html#interval
+.. _BED: ${static_path}/formatHelp.html#bed
+.. _Dataset missing?: ${static_path}/formatHelp.html
-----
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/fastx_toolkit/fasta_clipping_histogram.xml
--- a/tools/fastx_toolkit/fasta_clipping_histogram.xml
+++ b/tools/fastx_toolkit/fasta_clipping_histogram.xml
@@ -1,6 +1,6 @@
<tool id="cshl_fasta_clipping_histogram" name="Length Distribution"><description>chart</description>
- <requirements><requirement type="package">fastx_toolkit</requirement></requirements>
+ <requirements><requirement type="package">fastx_toolkit</requirement></requirements><command>fasta_clipping_histogram.pl $input $outfile</command><inputs>
@@ -25,13 +25,13 @@
In the following library, most sequences are 24-mers to 27-mers.
This could indicate an abundance of endo-siRNAs (depending of course of what you've tried to sequence in the first place).
-.. image:: ./static/fastx_icons/fasta_clipping_histogram_1.png
+.. image:: ${static_path}/fastx_icons/fasta_clipping_histogram_1.png
In the following library, most sequences are 19,22 or 23-mers.
This could indicate an abundance of miRNAs (depending of course of what you've tried to sequence in the first place).
-.. image:: ./static/fastx_icons/fasta_clipping_histogram_2.png
+.. image:: ${static_path}/fastx_icons/fasta_clipping_histogram_2.png
-----
@@ -81,7 +81,7 @@
Each sequence is counts as one, to produce the following chart:
-.. image:: ./static/fastx_icons/fasta_clipping_histogram_3.png
+.. image:: ${static_path}/fastx_icons/fasta_clipping_histogram_3.png
Example 2 - The following FASTA file have multiplicity counts::
@@ -95,7 +95,7 @@
The first sequence counts as 2, the second as 10, the third as 3, to produce the following chart:
-.. image:: ./static/fastx_icons/fasta_clipping_histogram_4.png
+.. image:: ${static_path}/fastx_icons/fasta_clipping_histogram_4.png
Use the **FASTA Collapser** tool to create FASTA files with multiplicity counts.
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/fastx_toolkit/fastq_quality_boxplot.xml
--- a/tools/fastx_toolkit/fastq_quality_boxplot.xml
+++ b/tools/fastx_toolkit/fastq_quality_boxplot.xml
@@ -32,16 +32,16 @@
An excellent quality library (median quality is 40 for almost all 36 cycles):
-.. image:: ./static/fastx_icons/fastq_quality_boxplot_1.png
+.. image:: ${static_path}/fastx_icons/fastq_quality_boxplot_1.png
A relatively good quality library (median quality degrades towards later cycles):
-.. image:: ./static/fastx_icons/fastq_quality_boxplot_2.png
+.. image:: ${static_path}/fastx_icons/fastq_quality_boxplot_2.png
A low quality library (median drops quickly):
-.. image:: ./static/fastx_icons/fastq_quality_boxplot_3.png
+.. image:: ${static_path}/fastx_icons/fastq_quality_boxplot_3.png
------
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/fastx_toolkit/fastx_barcode_splitter.xml
--- a/tools/fastx_toolkit/fastx_barcode_splitter.xml
+++ b/tools/fastx_toolkit/fastx_barcode_splitter.xml
@@ -1,6 +1,6 @@
<tool id="cshl_fastx_barcode_splitter" name="Barcode Splitter"><description></description>
- <requirements><requirement type="package">fastx_toolkit</requirement></requirements>
+ <requirements><requirement type="package">fastx_toolkit</requirement></requirements><command interpreter="bash">fastx_barcode_splitter_galaxy_wrapper.sh $BARCODE $input "$input.name" "$output.files_path" --mismatches $mismatches --partial $partial $EOL > $output </command><inputs>
@@ -62,7 +62,7 @@
**Output Example**
-.. image:: ./static/fastx_icons/barcode_splitter_output_example.png
+.. image:: ${static_path}/fastx_icons/barcode_splitter_output_example.png
------
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/fastx_toolkit/fastx_clipper.xml
--- a/tools/fastx_toolkit/fastx_clipper.xml
+++ b/tools/fastx_toolkit/fastx_clipper.xml
@@ -1,6 +1,6 @@
<tool id="cshl_fastx_clipper" name="Clip" version="1.0.1" ><description>adapter sequences</description>
- <requirements><requirement type="package">fastx_toolkit</requirement></requirements>
+ <requirements><requirement type="package">fastx_toolkit</requirement></requirements><command>
zcat -f $input | fastx_clipper -l $minlength -a $clip_source.clip_sequence -d $keepdelta -o $output -v $KEEP_N $DISCARD_OPTIONS
#if $input.ext == "fastqsanger":
@@ -82,7 +82,7 @@
**Clipping Illustration:**
-.. image:: ./static/fastx_icons/fastx_clipper_illustration.png
+.. image:: ${static_path}/fastx_icons/fastx_clipper_illustration.png
@@ -93,7 +93,7 @@
**Clipping Example:**
-.. image:: ./static/fastx_icons/fastx_clipper_example.png
+.. image:: ${static_path}/fastx_icons/fastx_clipper_example.png
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/fastx_toolkit/fastx_nucleotides_distribution.xml
--- a/tools/fastx_toolkit/fastx_nucleotides_distribution.xml
+++ b/tools/fastx_toolkit/fastx_nucleotides_distribution.xml
@@ -1,6 +1,6 @@
<tool id="cshl_fastx_nucleotides_distribution" name="Draw nucleotides distribution chart"><description></description>
- <requirements><requirement type="package">fastx_toolkit</requirement></requirements>
+ <requirements><requirement type="package">fastx_toolkit</requirement></requirements><command>fastx_nucleotide_distribution_graph.sh -t '$input.name' -i $input -o $output</command><inputs>
@@ -26,19 +26,19 @@
The following chart clearly shows the barcode used at the 5'-end of the library: **GATCT**
-.. image:: ./static/fastx_icons/fastq_nucleotides_distribution_1.png
+.. image:: ${static_path}/fastx_icons/fastq_nucleotides_distribution_1.png
In the following chart, one can almost 'read' the most abundant sequence by looking at the dominant values: **TGATA TCGTA TTGAT GACTG AA...**
-.. image:: ./static/fastx_icons/fastq_nucleotides_distribution_2.png
+.. image:: ${static_path}/fastx_icons/fastq_nucleotides_distribution_2.png
The following chart shows a growing number of unknown (N) nucleotides towards later cycles (which might indicate a sequencing problem):
-.. image:: ./static/fastx_icons/fastq_nucleotides_distribution_3.png
+.. image:: ${static_path}/fastx_icons/fastq_nucleotides_distribution_3.png
But most of the time, the chart will look rather random:
-.. image:: ./static/fastx_icons/fastq_nucleotides_distribution_4.png
+.. image:: ${static_path}/fastx_icons/fastq_nucleotides_distribution_4.png
------
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/maf/interval2maf.xml
--- a/tools/maf/interval2maf.xml
+++ b/tools/maf/interval2maf.xml
@@ -110,7 +110,7 @@
Here a single interval is superimposed on three MAF blocks. Blocks 1 and 3 are trimmed because they extend beyond boundaries of the interval:
-.. image:: ./static/images/maf_icons/interval2maf.png
+.. image:: ${static_path}/images/maf_icons/interval2maf.png
-------
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/maf/interval2maf_pairwise.xml
--- a/tools/maf/interval2maf_pairwise.xml
+++ b/tools/maf/interval2maf_pairwise.xml
@@ -37,7 +37,7 @@
Here a single interval is superimposed on three MAF blocks. Blocks 1 and 3 are trimmed because they extend beyond boundaries of the interval:
-.. image:: ./static/images/maf_icons/interval2maf.png
+.. image:: ${static_path}/images/maf_icons/interval2maf.png
------
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/maf/interval_maf_to_merged_fasta.xml
--- a/tools/maf/interval_maf_to_merged_fasta.xml
+++ b/tools/maf/interval_maf_to_merged_fasta.xml
@@ -101,7 +101,7 @@
Here three MAF blocks overlapping a single interval are stitched together. Space between blocks 2 and 3 is filled with gaps:
-.. image:: ./static/images/maf_icons/stitchMaf.png
+.. image:: ${static_path}/images/maf_icons/stitchMaf.png
------
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/metag_tools/blat_mapping.xml
--- a/tools/metag_tools/blat_mapping.xml
+++ b/tools/metag_tools/blat_mapping.xml
@@ -35,7 +35,7 @@
Showing reads coverage on human chromosome 22 (partial result) in UCSC Genome Browser Custom Track:
- .. image:: ./static/images/blat_mapping_example.png
+ .. image:: ${static_path}/images/blat_mapping_example.png
:width: 600
</help>
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/metag_tools/convert_SOLiD_color2nuc.xml
--- a/tools/metag_tools/convert_SOLiD_color2nuc.xml
+++ b/tools/metag_tools/convert_SOLiD_color2nuc.xml
@@ -65,7 +65,7 @@
Each di-nucleotide is represented by a single digit: 0 to 3. The matrix is symmetric, thus the leading nucleotide is necessary to determine the sequence (otherwise there are four possibilities).
- .. image:: ./static/images/dualcolorcode.png
+ .. image:: ${static_path}/images/dualcolorcode.png
</help>
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/metag_tools/short_reads_figure_score.xml
--- a/tools/metag_tools/short_reads_figure_score.xml
+++ b/tools/metag_tools/short_reads_figure_score.xml
@@ -56,7 +56,7 @@
Quality scores are summarized as boxplot (Roche 454 FLX data):
-.. image:: ./static/images/short_reads_boxplot.png
+.. image:: ${static_path}/images/short_reads_boxplot.png
where the **X-axis** is coordinate along the read and the **Y-axis** is quality score adjusted to comply with the Phred score metric. Units on the X-axis depend on whether your data comes from Roche (454) or Illumina (Solexa) and ABI SOLiD machines:
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/mutation/visualize.xml
--- a/tools/mutation/visualize.xml
+++ b/tools/mutation/visualize.xml
@@ -96,7 +96,7 @@
Visualization output:
-.. image:: ./static/images/mutation_visualization_example.png
+.. image:: ${static_path}/images/mutation_visualization_example.png
:width: 150
Here the left-most column represents the position and the background color is the reference base color. Each column on its right describe each sample.
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/new_operations/basecoverage.xml
--- a/tools/new_operations/basecoverage.xml
+++ b/tools/new_operations/basecoverage.xml
@@ -38,7 +38,7 @@
**Example**
-.. image:: ./static/operation_icons/gops_baseCoverage.gif
+.. image:: ${static_path}/operation_icons/gops_baseCoverage.gif
</help>
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/new_operations/cluster.xml
--- a/tools/new_operations/cluster.xml
+++ b/tools/new_operations/cluster.xml
@@ -86,11 +86,11 @@
Find Clusters:
-.. image:: ./static/operation_icons/gops_clusterFind.gif
+.. image:: ${static_path}/operation_icons/gops_clusterFind.gif
Merge Clusters:
-.. image:: ./static/operation_icons/gops_clusterMerge.gif
+.. image:: ${static_path}/operation_icons/gops_clusterMerge.gif
</help></tool>
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/new_operations/complement.xml
--- a/tools/new_operations/complement.xml
+++ b/tools/new_operations/complement.xml
@@ -55,7 +55,7 @@
**Example**
-.. image:: ./static/operation_icons/gops_complement.gif
+.. image:: ${static_path}/operation_icons/gops_complement.gif
</help></tool>
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/new_operations/concat.xml
--- a/tools/new_operations/concat.xml
+++ b/tools/new_operations/concat.xml
@@ -53,7 +53,7 @@
**Example**
-.. image:: ./static/operation_icons/gops_concatenate.gif
+.. image:: ${static_path}/operation_icons/gops_concatenate.gif
</help></tool>
\ No newline at end of file
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/new_operations/get_flanks.xml
--- a/tools/new_operations/get_flanks.xml
+++ b/tools/new_operations/get_flanks.xml
@@ -58,7 +58,7 @@
chr22 500 800 NM_174568 0 +
-.. image:: ./static/operation_icons/flanks_ex1.gif
+.. image:: ${static_path}/operation_icons/flanks_ex1.gif
**Example 2**
@@ -70,7 +70,7 @@
chr22 500 800 NM_028946 0 -
-.. image:: ./static/operation_icons/flanks_ex2.gif
+.. image:: ${static_path}/operation_icons/flanks_ex2.gif
</help>
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/new_operations/intersect.xml
--- a/tools/new_operations/intersect.xml
+++ b/tools/new_operations/intersect.xml
@@ -133,11 +133,11 @@
Overlapping Intervals:
-.. image:: ./static/operation_icons/gops_intersectOverlappingIntervals.gif
+.. image:: ${static_path}/operation_icons/gops_intersectOverlappingIntervals.gif
Overlapping Pieces of Intervals:
-.. image:: ./static/operation_icons/gops_intersectOverlappingPieces.gif
+.. image:: ${static_path}/operation_icons/gops_intersectOverlappingPieces.gif
</help></tool>
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/new_operations/join.xml
--- a/tools/new_operations/join.xml
+++ b/tools/new_operations/join.xml
@@ -94,23 +94,23 @@
**Examples**
-.. image:: ./static/operation_icons/gops_joinRecordsList.gif
+.. image:: ${static_path}/operation_icons/gops_joinRecordsList.gif
Only records that are joined (inner join):
-.. image:: ./static/operation_icons/gops_joinInner.gif
+.. image:: ${static_path}/operation_icons/gops_joinInner.gif
All records of first dataset:
-.. image:: ./static/operation_icons/gops_joinLeftOuter.gif
+.. image:: ${static_path}/operation_icons/gops_joinLeftOuter.gif
All records of second dataset:
-.. image:: ./static/operation_icons/gops_joinRightOuter.gif
+.. image:: ${static_path}/operation_icons/gops_joinRightOuter.gif
All records of both datasets:
-.. image:: ./static/operation_icons/gops_joinFullOuter.gif
+.. image:: ${static_path}/operation_icons/gops_joinFullOuter.gif
</help>
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/new_operations/merge.xml
--- a/tools/new_operations/merge.xml
+++ b/tools/new_operations/merge.xml
@@ -52,7 +52,7 @@
**Example**
-.. image:: ./static/operation_icons/gops_merge.gif
+.. image:: ${static_path}/operation_icons/gops_merge.gif
</help></tool>
\ No newline at end of file
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/new_operations/subtract.xml
--- a/tools/new_operations/subtract.xml
+++ b/tools/new_operations/subtract.xml
@@ -114,11 +114,11 @@
Intervals with no overlap:
-.. image:: ./static/operation_icons/gops_subtractOverlappingIntervals.gif
+.. image:: ${static_path}/operation_icons/gops_subtractOverlappingIntervals.gif
Non-overlapping pieces of intervals:
-.. image:: ./static/operation_icons/gops_subtractOverlappingPieces.gif
+.. image:: ${static_path}/operation_icons/gops_subtractOverlappingPieces.gif
</help></tool>
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/ngs_simulation/ngs_simulation.xml
--- a/tools/ngs_simulation/ngs_simulation.xml
+++ b/tools/ngs_simulation/ngs_simulation.xml
@@ -188,7 +188,7 @@
Plot output (png):
-.. image:: ./static/images/ngs_simulation.png
+.. image:: ${static_path}/images/ngs_simulation.png
Summary output (txt)::
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/phenotype_association/beam.xml
--- a/tools/phenotype_association/beam.xml
+++ b/tools/phenotype_association/beam.xml
@@ -59,9 +59,9 @@
The input dataset must be in lped_ format. The output datasets are both tabular_.
(`Dataset missing?`_)
-.. _lped: ./static/formatHelp.html#lped
-.. _tabular: ./static/formatHelp.html#tabular
-.. _Dataset missing?: ./static/formatHelp.html
+.. _lped: ${static_path}/formatHelp.html#lped
+.. _tabular: ${static_path}/formatHelp.html#tabular
+.. _Dataset missing?: ${static_path}/formatHelp.html
-----
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/phenotype_association/ctd.xml
--- a/tools/phenotype_association/ctd.xml
+++ b/tools/phenotype_association/ctd.xml
@@ -246,7 +246,7 @@
Home page: http://ctdbase.org
-.. _tabular: ./static/formatHelp.html#tab
+.. _tabular: ${static_path}/formatHelp.html#tab
-----
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/phenotype_association/funDo.xml
--- a/tools/phenotype_association/funDo.xml
+++ b/tools/phenotype_association/funDo.xml
@@ -34,7 +34,7 @@
There is no input dataset. The output is in interval_ format.
-.. _interval: ./static/formatHelp.html#interval
+.. _interval: ${static_path}/formatHelp.html#interval
-----
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/phenotype_association/gpass.xml
--- a/tools/phenotype_association/gpass.xml
+++ b/tools/phenotype_association/gpass.xml
@@ -39,9 +39,9 @@
The input dataset must be in lped_ format, and the output is tabular_.
(`Dataset missing?`_)
-.. _lped: ./static/formatHelp.html#lped
-.. _tabular: ./static/formatHelp.html#tab
-.. _Dataset missing?: ./static/formatHelp.html
+.. _lped: ${static_path}/formatHelp.html#lped
+.. _tabular: ${static_path}/formatHelp.html#tab
+.. _Dataset missing?: ${static_path}/formatHelp.html
-----
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/phenotype_association/hilbertvis.xml
--- a/tools/phenotype_association/hilbertvis.xml
+++ b/tools/phenotype_association/hilbertvis.xml
@@ -63,8 +63,8 @@
The input format is interval_, and the output is an image in PDF format.
(`Dataset missing?`_)
-.. _interval: ./static/formatHelp.html#interval
-.. _Dataset missing?: ./static/formatHelp.html
+.. _interval: ${static_path}/formatHelp.html#interval
+.. _Dataset missing?: ${static_path}/formatHelp.html
-----
@@ -75,7 +75,7 @@
visualization onto a two-dimensional square. For example, here is a diagram
showing the path of a level-2 Hilbert curve.
-.. image:: ./static/images/hilbertvisDiagram.png
+.. image:: ${static_path}/images/hilbertvisDiagram.png
The shade of each pixel represents the value for the corresponding bin of
consecutive genomic positions, calculated according to the specified
@@ -99,11 +99,11 @@
Here are some examples from the HilbertVis homepage, using ChIP-Seq data.
-.. image:: ./static/images/hilbertvis1.png
+.. image:: ${static_path}/images/hilbertvis1.png
-----
-.. image:: ./static/images/hilbertvis2.png
+.. image:: ${static_path}/images/hilbertvis2.png
-----
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/phenotype_association/ldtools.xml
--- a/tools/phenotype_association/ldtools.xml
+++ b/tools/phenotype_association/ldtools.xml
@@ -34,8 +34,8 @@
The input and output datasets are tabular_.
(`Dataset missing?`_)
-.. _tabular: ./static/formatHelp.html#tab
-.. _Dataset missing?: ./static/formatHelp.html
+.. _tabular: ${static_path}/formatHelp.html#tab
+.. _Dataset missing?: ${static_path}/formatHelp.html
-----
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/phenotype_association/linkToDavid.xml
--- a/tools/phenotype_association/linkToDavid.xml
+++ b/tools/phenotype_association/linkToDavid.xml
@@ -76,9 +76,9 @@
a link to the DAVID website as described below.
(`Dataset missing?`_)
-.. _tabular: ./static/formatHelp.html#tab
-.. _html: ./static/formatHelp.html#html
-.. _Dataset missing?: ./static/formatHelp.html
+.. _tabular: ${static_path}/formatHelp.html#tab
+.. _html: ${static_path}/formatHelp.html#html
+.. _Dataset missing?: ${static_path}/formatHelp.html
-----
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/phenotype_association/linkToGProfile.xml
--- a/tools/phenotype_association/linkToGProfile.xml
+++ b/tools/phenotype_association/linkToGProfile.xml
@@ -48,9 +48,9 @@
The output dataset is html_ with a link to g:Profiler.
(`Dataset missing?`_)
-.. _tabular: ./static/formatHelp.html#tab
-.. _html: ./static/formatHelp.html#html
-.. _Dataset missing?: ./static/formatHelp.html
+.. _tabular: ${static_path}/formatHelp.html#tab
+.. _html: ${static_path}/formatHelp.html#html
+.. _Dataset missing?: ${static_path}/formatHelp.html
-----
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/phenotype_association/lps.xml
--- a/tools/phenotype_association/lps.xml
+++ b/tools/phenotype_association/lps.xml
@@ -180,9 +180,9 @@
There is a second output dataset (a log) that is in text_ format.
(`Dataset missing?`_)
-.. _tabular: ./static/formatHelp.html#tab
-.. _text: ./static/formatHelp.html#text
-.. _Dataset missing?: ./static/formatHelp.html
+.. _tabular: ${static_path}/formatHelp.html#tab
+.. _text: ${static_path}/formatHelp.html#text
+.. _Dataset missing?: ${static_path}/formatHelp.html
-----
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/phenotype_association/pass.xml
--- a/tools/phenotype_association/pass.xml
+++ b/tools/phenotype_association/pass.xml
@@ -39,9 +39,9 @@
The input is in GFF_ format, and the output is tabular_.
(`Dataset missing?`_)
-.. _GFF: ./static/formatHelp.html#gff
-.. _tabular: ./static/formatHelp.html#tab
-.. _Dataset missing?: ./static/formatHelp.html
+.. _GFF: ${static_path}/formatHelp.html#gff
+.. _tabular: ${static_path}/formatHelp.html#tab
+.. _Dataset missing?: ${static_path}/formatHelp.html
-----
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/phenotype_association/sift.xml
--- a/tools/phenotype_association/sift.xml
+++ b/tools/phenotype_association/sift.xml
@@ -97,8 +97,8 @@
The input and output datasets are tabular_.
(`Dataset missing?`_)
-.. _tabular: ./static/formatHelp.html#tab
-.. _Dataset missing?: ./static/formatHelp.html
+.. _tabular: ${static_path}/formatHelp.html#tab
+.. _Dataset missing?: ${static_path}/formatHelp.html
-----
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/phenotype_association/snpFreq.xml
--- a/tools/phenotype_association/snpFreq.xml
+++ b/tools/phenotype_association/snpFreq.xml
@@ -44,8 +44,8 @@
and includes all of the input data plus the additional columns described below.
(`Dataset missing?`_)
-.. _tabular: ./static/formatHelp.html#tab
-.. _Dataset missing?: ./static/formatHelp.html
+.. _tabular: ${static_path}/formatHelp.html#tab
+.. _Dataset missing?: ${static_path}/formatHelp.html
-----
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/plotting/bar_chart.xml
--- a/tools/plotting/bar_chart.xml
+++ b/tools/plotting/bar_chart.xml
@@ -52,7 +52,7 @@
Graphing columns 2 and 3 while using column 1 for X Tick Labels will produce the following plot:
-.. image:: ./static/images/bar_chart.png
+.. image:: ${static_path}/images/bar_chart.png
:height: 324
:width: 540
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/plotting/boxplot.xml
--- a/tools/plotting/boxplot.xml
+++ b/tools/plotting/boxplot.xml
@@ -95,7 +95,7 @@
* Rectangular red boxes show the Inter-quartile Range (IQR) (top value is Q3, bottom value is Q1)
* Whiskers show outliers at max. 1.5*IQR
-.. image:: ./static/images/solid_qual.png
+.. image:: ${static_path}/images/solid_qual.png
------
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/plotting/histogram2.xml
--- a/tools/plotting/histogram2.xml
+++ b/tools/plotting/histogram2.xml
@@ -70,7 +70,7 @@
- Create a histogram on column 2 of the above dataset.
-.. image:: ./static/images/histogram2.png
+.. image:: ${static_path}/images/histogram2.png
</help></tool>
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/plotting/scatterplot.xml
--- a/tools/plotting/scatterplot.xml
+++ b/tools/plotting/scatterplot.xml
@@ -65,7 +65,7 @@
- Create a simple scatterplot between the variables in column 2 and column 3 of the above dataset.
-.. image:: ./static/images/scatterplot.png
+.. image:: ${static_path}/images/scatterplot.png
</help></tool>
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/plotting/xy_plot.xml
--- a/tools/plotting/xy_plot.xml
+++ b/tools/plotting/xy_plot.xml
@@ -143,6 +143,6 @@
- Series 1: Red Dashed-Line plot between columns 1 and 2
- Series 2: Blue Circular-Point plot between columns 3 and 2
-.. image:: ./static/images/xy_example.jpg
+.. image:: ${static_path}/images/xy_example.jpg
</help></tool>
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/regVariation/compute_q_values.xml
--- a/tools/regVariation/compute_q_values.xml
+++ b/tools/regVariation/compute_q_values.xml
@@ -141,13 +141,13 @@
0.03115264 0.009750824 1
-.. image:: ./static/operation_icons/p_hist.png
+.. image:: ${static_path}/operation_icons/p_hist.png
-.. image:: ./static/operation_icons/q_hist.png
+.. image:: ${static_path}/operation_icons/q_hist.png
-.. image:: ./static/operation_icons/Q_plots.png
+.. image:: ${static_path}/operation_icons/Q_plots.png
</help>
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/regVariation/draw_stacked_barplots.xml
--- a/tools/regVariation/draw_stacked_barplots.xml
+++ b/tools/regVariation/draw_stacked_barplots.xml
@@ -52,7 +52,7 @@
The stacked bars plot representing the data in the input file.
-.. image:: ./static/operation_icons/stacked_bars_plot.png
+.. image:: ${static_path}/operation_icons/stacked_bars_plot.png
</help>
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/rgenetics/rgManQQ.xml
--- a/tools/rgenetics/rgManQQ.xml
+++ b/tools/rgenetics/rgManQQ.xml
@@ -86,7 +86,7 @@
improbable p values are above the red line which is drawn at the Bonferroni FWER control level (0.05/n
where n is the number of tests - this is highly conservative for correlated SNPs typical of GWA)
-.. image:: ./static/images/Armitagep_manhattan.png
+.. image:: ${static_path}/images/Armitagep_manhattan.png
A quantile-quantile (QQ) plot is a good way to see systematic departures from the null expectation of
uniform p-values from a genomic analysis. If the QQ plot shows departure from the null (ie a uniform 0-1
@@ -94,7 +94,7 @@
interesting results to look at. A log scale will help emphasise departures from the null at low p values
more clear
-.. image:: ./static/images/Armitagep_qqplot.png
+.. image:: ${static_path}/images/Armitagep_qqplot.png
-----
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/rgenetics/rgWebLogo3.xml
--- a/tools/rgenetics/rgWebLogo3.xml
+++ b/tools/rgenetics/rgWebLogo3.xml
@@ -106,7 +106,7 @@
A typical output looks like this
-.. image:: ./static/images/rgWebLogo3_test.jpg
+.. image:: ${static_path}/images/rgWebLogo3_test.jpg
----
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/samtools/pileup_parser.xml
--- a/tools/samtools/pileup_parser.xml
+++ b/tools/samtools/pileup_parser.xml
@@ -320,7 +320,7 @@
To call all variants (with no restriction by coverage) with quality above phred value of 20, we will need to set the parameters as follows:
-.. image:: ./static/images/pileup_parser_help1.png
+.. image:: ${static_path}/images/pileup_parser_help1.png
Running the tool with these parameters will return::
@@ -336,7 +336,7 @@
In addition to calling variants, it is often useful to know the quality adjusted coverage. Running the tool with these parameters:
-.. image:: ./static/images/pileup_parser_help2.png
+.. image:: ${static_path}/images/pileup_parser_help2.png
will report everything from the original file::
@@ -355,7 +355,7 @@
If you set the **Print total number of differences?** to **Yes** the tool will print an additional column with the total number of reads where a devinat base is above the quality threshold. So, seetiing parametrs like this:
-.. image:: ./static/images/pileup_parser_help3.png
+.. image:: ${static_path}/images/pileup_parser_help3.png
will produce this::
@@ -371,7 +371,7 @@
Setting **Print quality and base string?** to **Yes** as shown here:
-.. image:: ./static/images/pileup_parser_help4.png
+.. image:: ${static_path}/images/pileup_parser_help4.png
will produce this::
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/solid_tools/solid_qual_boxplot.xml
--- a/tools/solid_tools/solid_qual_boxplot.xml
+++ b/tools/solid_tools/solid_qual_boxplot.xml
@@ -29,7 +29,7 @@
* Whiskers show outliers at max. 1.5*IQR
-.. image:: ./static/images/solid_qual.png
+.. image:: ${static_path}/images/solid_qual.png
------
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/stats/cor.xml
--- a/tools/stats/cor.xml
+++ b/tools/stats/cor.xml
@@ -47,19 +47,19 @@
- **Pearson's Correlation** reflects the degree of linear relationship between two variables. It ranges from +1 to -1. A correlation of +1 means that there is a perfect positive linear relationship between variables. The formula for Pearson's correlation is:
- .. image:: ./static/images/pearson.png
+ .. image:: ${static_path}/images/pearson.png
where n is the number of items
- **Kendall's rank correlation** is used to measure the degree of correspondence between two rankings and assessing the significance of this correspondence. The formula for Kendall's rank correlation is:
- .. image:: ./static/images/kendall.png
+ .. image:: ${static_path}/images/kendall.png
where n is the number of items, and P is the sum.
- **Spearman's rank correlation** assesses how well an arbitrary monotonic function could describe the relationship between two variables, without making any assumptions about the frequency distribution of the variables. The formula for Spearman's rank correlation is
- .. image:: ./static/images/spearman.png
+ .. image:: ${static_path}/images/spearman.png
where D is the difference between the ranks of corresponding values of X and Y, and N is the number of pairs of values.
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/stats/generate_matrix_for_pca_lda.xml
--- a/tools/stats/generate_matrix_for_pca_lda.xml
+++ b/tools/stats/generate_matrix_for_pca_lda.xml
@@ -35,12 +35,12 @@
- Input file (Source file First)
-.. image:: ./static/images/tools/lda/first_matrix_generator_example_file.png
+.. image:: ${static_path}/images/tools/lda/first_matrix_generator_example_file.png
- Input file (Source file Second)
-.. image:: ./static/images/tools/lda/second_matrix_generator_example_file.png
+.. image:: ${static_path}/images/tools/lda/second_matrix_generator_example_file.png
</help>
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/taxonomy/gi2taxonomy.xml
--- a/tools/taxonomy/gi2taxonomy.xml
+++ b/tools/taxonomy/gi2taxonomy.xml
@@ -50,7 +50,7 @@
and you want to obtain full taxonomic representation for GIs listed in *targetGI* column. If you set parameters as shown here:
-.. image:: ./static/images/fetchTax.png
+.. image:: ${static_path}/images/fetchTax.png
the tool will generate the following output (you may need to scroll sideways to see the entire line)::
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/taxonomy/poisson2test.xml
--- a/tools/taxonomy/poisson2test.xml
+++ b/tools/taxonomy/poisson2test.xml
@@ -48,12 +48,12 @@
Equation 1:
-.. image:: ./static/images/poisson2test_eqn1.png
+.. image:: ${static_path}/images/poisson2test_eqn1.png
Equation 2:
-.. image:: ./static/images/poisson2test_eqn2.png
+.. image:: ${static_path}/images/poisson2test_eqn2.png
X = number of reads falling in a particular taxon in location 1
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc tools/taxonomy/t2ps_wrapper.xml
--- a/tools/taxonomy/t2ps_wrapper.xml
+++ b/tools/taxonomy/t2ps_wrapper.xml
@@ -62,14 +62,14 @@
Drawing the tree with default parameters (without changing anything in the interface) will produce this tree:
-.. image:: ./static/images/t2ps_ideal.png
+.. image:: ${static_path}/images/t2ps_ideal.png
:width: 500
(for explanation of colors and numbers on the tree scroll to the bottom of this help section)
Here *Class* rank represent terminal nodes (leaves) of the tree because it is the default setting of the "*show ranks from root to*" drop-down. Changing the drop-down to "*Subspecies*" will produce this:
-.. image:: ./static/images/t2ps_ideal_ssp.png
+.. image:: ${static_path}/images/t2ps_ideal_ssp.png
:width: 1000
--------
@@ -87,7 +87,7 @@
A full tree for this dataset will look like this:
-.. image:: ./static/images/t2ps_missing_nodes.png
+.. image:: ${static_path}/images/t2ps_missing_nodes.png
:width: 1000
Missing nodes are simply omitted from the tree (there are no gray boxes corresponding to "n") but the branch length is maintained so that taxa belonging to the same taxonomic rank are always aligned with each other
@@ -98,11 +98,11 @@
You can use the "*maximum number of leaves*" to restrict the tree to a specified number of leaves (external nodes). Using the following setting on the above dataset (note *show ranks from root to* set to *show entire tree* and *maximum number of leaves* is set *3*):
-.. image:: ./static/images/t2ps_autoscale.png
+.. image:: ${static_path}/images/t2ps_autoscale.png
will produce this tree:
-.. image:: ./static/images/t2ps_autoscale_tree.png
+.. image:: ${static_path}/images/t2ps_autoscale_tree.png
:width: 1000
Here the tree is automatically trimmed at a taxonomic rank that will only have 3 outer nodes. This is very useful for initial evaluation of very large trees where you want to only see, say, 1,000 outer nodes at once.
@@ -113,11 +113,11 @@
Branches of the tree are colored according to the heatmap below. The "bluer" the branch the lesser the number of leaves it leads to and vice versa.
-.. image:: ./static/images/t2ps_heatmap.png
+.. image:: ${static_path}/images/t2ps_heatmap.png
Each node is labeled with taxonomic name and the number of tree leaves belonging to this taxonomic group:
-.. image:: ./static/images/t2ps_node_label.png
+.. image:: ${static_path}/images/t2ps_node_label.png
Repository URL: https://bitbucket.org/galaxy/galaxy-central/
--
This is a commit notification from bitbucket.org. You are receiving
this because you have the service enabled, addressing the recipient of
this email.
1 new commit in galaxy-central:
https://bitbucket.org/galaxy/galaxy-central/changeset/ba56d4746f7a/
changeset: ba56d4746f7a
user: carlfeberhard
date: 2012-08-03 19:31:48
summary: minor docstring adds in /scripts
affected #: 7 files
diff -r 53aacf94c5fc2e837975d15cc1bcc22d146db659 -r ba56d4746f7ade81c3cd7caf8d0d66a437ae7087 scripts/check_eggs.py
--- a/scripts/check_eggs.py
+++ b/scripts/check_eggs.py
@@ -1,7 +1,11 @@
#!/usr/bin/env python
"""
-usage: check_eggs.py
+Compares local dependency eggs to those in eggs.ini, displaying a warning if
+any are out of date.
+
+usage: check_eggs.py [options]
"""
+
import os, sys, logging
from optparse import OptionParser
diff -r 53aacf94c5fc2e837975d15cc1bcc22d146db659 -r ba56d4746f7ade81c3cd7caf8d0d66a437ae7087 scripts/check_python.py
--- a/scripts/check_python.py
+++ b/scripts/check_python.py
@@ -1,3 +1,8 @@
+"""
+If the current installed python version is not 2.5 to 2.7, prints an error
+message to stderr and returns 1
+"""
+
import os, sys
msg = """ERROR: Your Python version is: %s
diff -r 53aacf94c5fc2e837975d15cc1bcc22d146db659 -r ba56d4746f7ade81c3cd7caf8d0d66a437ae7087 scripts/create_db.py
--- a/scripts/create_db.py
+++ b/scripts/create_db.py
@@ -1,3 +1,21 @@
+"""
+Creates the initial galaxy database schema using the settings defined in
+universe_wsgi.ini.
+
+This script is also wrapped by create_db.sh.
+
+.. note: pass '-c /location/to/your_config.ini' for non-standard ini file
+locations.
+
+.. note: if no database_connection is set in universe_wsgi.ini, the default,
+sqlite database will be constructed.
+ Using the database_file setting in universe_wsgi.ini will create the file
+ at the settings location (??)
+
+.. seealso: universe_wsgi.ini, specifically the settings: database_connection
+and database file
+"""
+
import sys, os.path, logging
new_path = [ os.path.join( os.getcwd(), "lib" ) ]
diff -r 53aacf94c5fc2e837975d15cc1bcc22d146db659 -r ba56d4746f7ade81c3cd7caf8d0d66a437ae7087 scripts/dist-scramble.py
--- a/scripts/dist-scramble.py
+++ b/scripts/dist-scramble.py
@@ -1,3 +1,36 @@
+"""
+Scrambles eggs for distribution on multiple platforms.
+
+(from http://wiki.g2.bx.psu.edu/Admin/Config/Eggs)
+This is mostly designed for use by Galaxy Developers at Penn State who are
+building eggs for distribution via the Galaxy Eggs distribution site.
+dist-scramble.py uses the dist-eggs.ini config file to determine what platforms
+to build for, and which hosts to build on.
+
+dist-scramble.py works the same way as scramble.py: ::
+
+% python scripts/dist-scramble.py galaxy_egg
+
+Called with only the egg argument, dist-scramble.py will build for all the
+platforms under the all group in its config file (for platform-specific eggs)
+or the noplatform group (for platform-inspecific eggs). The [[hosts]|section
+contains information about which hosts will be used for building on each desired
+platform. If you don't want to build for all the platforms listed under the all
+group, you can add a platform argument (any lvalue in the [hosts]] or [groups]
+section is valid): ::
+
+% python scripts/dist-scramble.py galaxy_egg linux
+
+The platform argument is ignored for platform-inspecific eggs. An assumption is
+made that your Galaxy distribution is located at the same place on all of the
+hosts on which you're building (i.e. via a network filesystem).
+
+Once dist-scramble.py finishes, it will output a list of platforms on which it
+failed to scramble the egg. Successful eggs will be put in a new dist-eggs
+subdirectory of your Galaxy distribution. These eggs can then be copied to your
+distribution site.
+"""
+
import os, sys, logging
from optparse import OptionParser
diff -r 53aacf94c5fc2e837975d15cc1bcc22d146db659 -r ba56d4746f7ade81c3cd7caf8d0d66a437ae7087 scripts/drmaa_external_killer.py
--- a/scripts/drmaa_external_killer.py
+++ b/scripts/drmaa_external_killer.py
@@ -1,4 +1,9 @@
#!/usr/bin/env python
+
+"""
+Terminates a DRMAA job if given a job id and (appropriate) user id.
+"""
+
import os
import sys
import errno
diff -r 53aacf94c5fc2e837975d15cc1bcc22d146db659 -r ba56d4746f7ade81c3cd7caf8d0d66a437ae7087 scripts/drmaa_external_runner.py
--- a/scripts/drmaa_external_runner.py
+++ b/scripts/drmaa_external_runner.py
@@ -1,4 +1,11 @@
#!/usr/bin/env python
+
+"""
+Submit a DRMAA job given a user id and a job template file (in JSON format)
+defining any or all of the following: args, remoteCommand, outputPath,
+errorPath, nativeSpecification, name, email, project
+"""
+
import os
import sys
import errno
diff -r 53aacf94c5fc2e837975d15cc1bcc22d146db659 -r ba56d4746f7ade81c3cd7caf8d0d66a437ae7087 scripts/fetch_eggs.py
--- a/scripts/fetch_eggs.py
+++ b/scripts/fetch_eggs.py
@@ -1,3 +1,10 @@
+"""
+Connects to the Galaxy Eggs distribution site and downloads any eggs needed.
+
+If eggs for your platform are unavailable, fetch_eggs.py will direct you to run
+scramble.py.
+"""
+
import os, sys, logging
from optparse import OptionParser
Repository URL: https://bitbucket.org/galaxy/galaxy-central/
--
This is a commit notification from bitbucket.org. You are receiving
this because you have the service enabled, addressing the recipient of
this email.
1 new commit in galaxy-central:
https://bitbucket.org/galaxy/galaxy-central/changeset/29680fa5c35e/
changeset: 29680fa5c35e
user: jgoecks
date: 2012-08-07 15:40:51
summary: Use mako template in tool help so that dynamic image paths can be used. Fixes #141
affected #: 58 files
diff -r 81692d707741d1933c3f7007148b59e7c9e28698 -r 29680fa5c35e6c22a6b7208015237b95d4bce2cc lib/galaxy/tools/__init__.py
--- a/lib/galaxy/tools/__init__.py
+++ b/lib/galaxy/tools/__init__.py
@@ -8,6 +8,7 @@
import logging, os, string, sys, tempfile, glob, shutil, types, urllib, subprocess, random, math, traceback
import simplejson
import binascii
+from mako.template import Template
from UserDict import DictMixin
from galaxy.util.odict import odict
from galaxy.util.bunch import Bunch
@@ -1068,7 +1069,8 @@
break
def parse_help( self, root ):
"""
Parse the help text for the tool. Formatted in reStructuredText.
This implementation supports multiple pages.
"""
# TODO: Allow raw HTML or an external link.
@@ -1080,7 +1082,7 @@
help_pages = self.help.findall( "page" )
help_header = self.help.text
try:
- self.help = util.rst_to_html(self.help.text)
+ self.help = Template( util.rst_to_html(self.help.text) )
except:
log.exception( "error in help for tool %s" % self.name )
# Multiple help page case
@@ -1090,7 +1092,7 @@
help_footer = help_footer + help_page.tail
# Each page has to rendered all-together because of backreferences allowed by rst
try:
- self.help_by_page = [ util.rst_to_html( help_header + x + help_footer )
+ self.help_by_page = [ Template( util.rst_to_html( help_header + x + help_footer ) )
for x in self.help_by_page ]
except:
log.exception( "error in multi-page help for tool %s" % self.name )
@@ -1068,7 +1069,8 @@
def parse_help( self, root ):
"""
- Parse the help text for the tool. Formatted in reStructuredText.
+ Parse the help text for the tool. Formatted in reStructuredText, but
+ stored as Mako to allow for dynamic image paths.
This implementation supports multiple pages.
"""
--
This is a commit notification from bitbucket.org. You are receiving
this because you have the service enabled, addressing the recipient of
this email.